==> jc-1.4.0.tar.gz: gnu/java/locale/LocaleInformation__5fsyr__5fSY.h <==
// public class gnu.java.locale.LocaleInformation_syr_SY

// class file dependencies
// @dep_class 900ce09e523a8c75 gnu_java_locale_LocaleInformation__5fsyr__5fSY
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fsyr__5fSY_H_
#define _JC_gnu_java_locale_LocaleInformation__5fsyr__5fSY_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$refs	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vmethods	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtable	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtype	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$fields_struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object *);

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object *);
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vmethods	gnu_java_locale_LocaleInformation__5fsyr__5fSY;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$refs {
    _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_refs	gnu_java_locale_LocaleInformation__5fsyr__5fSY;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_nonrefs	gnu_java_locale_LocaleInformation__5fsyr__5fSY;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object {
	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtype _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fsyr__5fSY, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fsyr__5fSY_H_ */

==> jc-1.4.5.tar.gz: gnu/java/locale/LocaleInformation__5fsyr__5fSY.h <==
// public class gnu.java.locale.LocaleInformation_syr_SY

// class file dependencies
// @dep_class 900ce09e523a8c75 gnu_java_locale_LocaleInformation__5fsyr__5fSY
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fsyr__5fSY_H_
#define _JC_gnu_java_locale_LocaleInformation__5fsyr__5fSY_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$refs	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vmethods	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtable	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtype	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$fields_struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vmethods	gnu_java_locale_LocaleInformation__5fsyr__5fSY;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$refs {
    _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_refs	gnu_java_locale_LocaleInformation__5fsyr__5fSY;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$sub_nonrefs	gnu_java_locale_LocaleInformation__5fsyr__5fSY;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$object {
	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$vtype _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fsyr__5fSY, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fsyr__5fSY$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fsyr__5fSY_H_ */
